@@ -21,25 +21,19 @@
 
 #include "analyzer.h"
 
-#include <KLocalizedString>
-
-#include "logging.h"
 #include "ksystemlogConfig.h"
+#include "logging.h"
 
 #include "logViewModel.h"
 
-#include "logMode.h"
 #include "logFileReader.h"
-
+#include "logMode.h"
 
 Analyzer::Analyzer(LogMode *mode)
     : QObject(nullptr)
-    , logViewModel(nullptr)
-    , logMode(mode)
-    , insertionLocking(QMutex::Recursive)
-    , logLineInternalIdGenerator(0)
+    , mLogMode(mode)
+    , mInsertionLocking()
 {
-    parsingPaused = false;
 }
 
 Analyzer::~Analyzer()
@@ -50,16 +44,16 @@ Analyzer::~Analyzer()
 
 bool Analyzer::isParsingPaused() const
 {
-    return parsingPaused;
+    return mParsingPaused;
 }
 
 void Analyzer::setParsingPaused(bool paused)
 {
-    parsingPaused = paused;
+    mParsingPaused = paused;
 
     bool watching;
     // If we resume the parsing, then parse files to know if new lines have been appended.
-    if (parsingPaused == true) {
+    if (mParsingPaused) {
         logDebug() << "Pausing reading";
         watching = false;
     } else {
@@ -72,17 +66,17 @@ void Analyzer::setParsingPaused(bool paused)
 
 void Analyzer::setLogViewModel(LogViewModel *logViewModel)
 {
-    this->logViewModel = logViewModel;
+    mLogViewModel = logViewModel;
 }
 
 void Analyzer::informOpeningProgress(int currentPosition, int total)
 {
-    int each = total / 100;
+    const int each = total / 100;
     if (each == 0) {
         return;
     }
 
     if (currentPosition % each == 0) {
-        emit openingProgressed();
+        Q_EMIT openingProgressed();
     }
 }
