@@ -22,10 +22,8 @@
 #ifndef LOG_MODE_CONFIGURATION_WIDGET_H
 #define LOG_MODE_CONFIGURATION_WIDGET_H
 
-#include <QWidget>
 #include <QString>
-
-class LogModeConfigurationWidgetPrivate;
+#include <QWidget>
 
 class LogModeConfigurationWidget : public QWidget
 {
@@ -34,7 +32,7 @@ class LogModeConfigurationWidget : public QWidget
 public:
     LogModeConfigurationWidget(const QString &itemName, const QString &iconName, const QString &header);
 
-    virtual ~LogModeConfigurationWidget();
+    ~LogModeConfigurationWidget() override;
 
     virtual bool isValid() const;
 
@@ -51,7 +49,9 @@ public:
     QString header() const;
 
 private:
-    LogModeConfigurationWidgetPrivate *const d;
+    QString mItemName;
+    QString mIconName;
+    QString mHeader;
 };
 
 #endif // _LOG_MODE_CONFIGURATION_WIDGET_H
