@@ -26,8 +26,6 @@
 
 #include "ui_loggerDialogBase.h"
 
-class LoggerDialogPrivate;
-
 class LoggerDialog : public QDialog, public Ui::LoggerDialogBase
 {
     Q_OBJECT
@@ -48,9 +46,12 @@ protected Q_SLOTS:
     void changeMessageActivation(bool activation);
 
 private:
+    void slotLinkClicked(const QString &link);
     void buildMaps();
+    QMap<QString, QString> mFacilities;
 
-    LoggerDialogPrivate *const d;
+    QMap<QString, QString> mPriorities;
+    QMap<QString, QIcon> mPriorityIcons;
 };
 
 #endif // _LOGGER_DIALOG_H
