@@ -26,43 +26,28 @@
 
 #include "logModeConfiguration.h"
 
-#include "logging.h"
 #include "defaults.h"
+#include "logging.h"
 
 #include "acpidLogMode.h"
 
 #include "ksystemlogConfig.h"
 
-class AcpidConfigurationPrivate
-{
-public:
-    QStringList acpidPaths;
-};
-
 class AcpidConfiguration : public LogModeConfiguration
 {
     Q_OBJECT
 
 public:
-    AcpidConfiguration()
-        : d(new AcpidConfigurationPrivate())
-    {
-        configuration->setCurrentGroup(QStringLiteral("AcpidLogMode"));
+    AcpidConfiguration();
 
-        QStringList defaultAcpidPaths;
-        defaultAcpidPaths << QStringLiteral("/var/log/acpid");
-        configuration->addItemStringList(QStringLiteral("LogFilesPaths"), d->acpidPaths, defaultAcpidPaths,
-                                         QStringLiteral("LogFilesPaths"));
-    }
+    ~AcpidConfiguration() override;
 
-    virtual ~AcpidConfiguration() { delete d; }
+    QStringList acpidPaths() const;
 
-    QStringList acpidPaths() const { return d->acpidPaths; }
-
-    void setAcpidPaths(const QStringList &acpidPaths) { d->acpidPaths = acpidPaths; }
+    void setAcpidPaths(const QStringList &acpidPaths);
 
 private:
-    AcpidConfigurationPrivate *const d;
+    QStringList mAcpidPaths;
 };
 
 #endif // _ACPID_CONFIGURATION_H
