@@ -31,32 +31,21 @@
 #include "logging.h"
 
 #include "logLine.h"
-#include "logViewWidgetItem.h"
 #include "logMode.h"
+#include "logViewWidgetItem.h"
 
 class ApacheItemBuilder : public LogModeItemBuilder
 {
 public:
-    ApacheItemBuilder() {}
-
-    virtual ~ApacheItemBuilder() {}
-
-    QString createFormattedText(LogLine *line) const override
+    ApacheItemBuilder()
     {
-        QString result;
-
-        QListIterator<QString> it(line->logItems());
-
-        result.append(QLatin1String("<table>"));
-
-        result.append(labelMessageFormat(i18n("Date:"), formatDate(line->time())));
-        result.append(labelMessageFormat(i18n("Level:"), line->logLevel()->name()));
-        result.append(labelMessageFormat(i18n("Client:"), it.next()));
-
-        result.append(QLatin1String("</table>"));
-
-        return result;
     }
+
+    ~ApacheItemBuilder() override
+    {
+    }
+
+    QString createFormattedText(LogLine *line) const override;
 };
 
 #endif // _APACHE_ITEM_BUILDER_H
