@@ -21,10 +21,10 @@
 
 #include "fileListHelper.h"
 
-#include <QObject>
 #include <QAction>
-#include <QPushButton>
 #include <QFileDialog>
+#include <QObject>
+#include <QPushButton>
 
 #include <KLocalizedString>
 #include <KMessageBox>
@@ -34,7 +34,7 @@
 #include "logging.h"
 
 FileListHelper::FileListHelper(QWidget *p)
-    : parent(p)
+    : mParent(p)
 {
 }
 
@@ -45,7 +45,7 @@ FileListHelper::~FileListHelper()
 QAction *FileListHelper::prepareButtonAndAction(QPushButton *button, const QIcon &icon)
 {
     // Initialize action
-    QAction *action = new QAction(button);
+    auto action = new QAction(button);
     action->setIcon(icon);
     action->setText(button->text());
 
@@ -61,8 +61,7 @@ QAction *FileListHelper::prepareButtonAndAction(QPushButton *button, const QIcon
     return action;
 }
 
-QAction *FileListHelper::prepareButtonAndAction(QPushButton *button, const QIcon &icon,
-                                                const QObject *receiver, const char *member)
+QAction *FileListHelper::prepareButtonAndAction(QPushButton *button, const QIcon &icon, const QObject *receiver, const char *member)
 {
     QAction *action = prepareButtonAndAction(button, icon);
     connect(button, SIGNAL(clicked(bool)), receiver, member);
@@ -70,8 +69,7 @@ QAction *FileListHelper::prepareButtonAndAction(QPushButton *button, const QIcon
     return action;
 }
 
-void FileListHelper::prepareButton(QPushButton *button, const QIcon &icon, const QObject *receiver,
-                                   const char *member, QWidget *fileList)
+void FileListHelper::prepareButton(QPushButton *button, const QIcon &icon, const QObject *receiver, const char *member, QWidget *fileList)
 {
     // Initialize action
     QAction *action = prepareButtonAndAction(button, icon, receiver, member);
@@ -82,7 +80,7 @@ QStringList FileListHelper::findPaths(const QList<QUrl> &urls)
 {
     QStringList paths;
 
-    for (QList<QUrl>::ConstIterator it = urls.constBegin(); it != urls.constEnd(); ++it) {
+    for (QList<QUrl>::ConstIterator it = urls.constBegin(), total = urls.constEnd(); it != total; ++it) {
         QUrl url(*it);
 
         if (isValidFile(url)) {
@@ -90,7 +88,7 @@ QStringList FileListHelper::findPaths(const QList<QUrl> &urls)
             if (url.fileName().contains(QLatin1Char('*'))) {
                 const QStringList foundPaths = expandJoker(url);
                 logDebug() << "Found paths of " << url.path() << ":" << foundPaths;
-                foreach (const QString &foundPath, foundPaths) {
+                for (const QString &foundPath : foundPaths) {
                     paths.append(foundPath);
                 }
             } else {
@@ -114,7 +112,7 @@ bool FileListHelper::isValidFile(const QUrl &url)
     // If it is not a local file
     if (!url.isLocalFile()) {
         message = i18n("'%1' is not a local file.", url.path());
-        KMessageBox::error(parent, message, i18n("File selection failed"), KMessageBox::Notify);
+        KMessageBox::error(mParent, message, i18n("File selection failed"), KMessageBox::Notify);
         return false;
     }
 
@@ -126,11 +124,9 @@ bool FileListHelper::isValidFile(const QUrl &url)
     return true;
 }
 
-QList<QUrl> FileListHelper::openUrls()
+QList<QUrl> FileListHelper::openUrls() const
 {
-    QFileDialog fileDialog(parent, QString(), QStringLiteral(DEFAULT_LOG_FOLDER), QLatin1String("*|") + i18n("All Files (*)")
-                                                                      + QLatin1String("\n*.log|")
-                                                                      + i18n("Log Files (*.log)"));
+    QFileDialog fileDialog(mParent, QString(), QStringLiteral(DEFAULT_LOG_FOLDER), i18n("All Files (*)") + QLatin1String(";;") + i18n("Log Files (*.log)"));
     fileDialog.setWindowTitle(i18n("Choose Log File"));
     fileDialog.setFileMode(QFileDialog::ExistingFiles);
 
@@ -138,20 +134,19 @@ QList<QUrl> FileListHelper::openUrls()
     return fileDialog.selectedUrls();
 }
 
-QUrl FileListHelper::openUrl(const QString &originPath)
+QUrl FileListHelper::openUrl(const QString &originPath) const
 {
-    QFileDialog fileDialog(parent, QString(), originPath, QLatin1String("*|") + i18n("All Files (*)")
-                                                              + QLatin1String("\n*.log|")
-                                                              + i18n("Log Files (*.log)"));
+    QFileDialog fileDialog(mParent, QString(), originPath, i18n("All Files (*)") + QLatin1String(";;") + i18n("Log Files (*.log)"));
     fileDialog.setWindowTitle(i18n("Choose Log File"));
     fileDialog.setFileMode(QFileDialog::AnyFile);
 
     fileDialog.exec();
-    QList<QUrl> urls = fileDialog.selectedUrls();
-    if (!urls.isEmpty())
+    const QList<QUrl> urls = fileDialog.selectedUrls();
+    if (!urls.isEmpty()) {
         return fileDialog.selectedUrls().at(0);
-    else
+    } else {
         return QUrl();
+    }
 }
 
 QStringList FileListHelper::expandJoker(const QUrl &url)
@@ -159,7 +154,7 @@ QStringList FileListHelper::expandJoker(const QUrl &url)
     const QFileInfo info(url.toLocalFile());
 
     logDebug() << "Dir " << info.dir().path();
-    QString filename = info.fileName();
+    const QString filename = info.fileName();
 
     if (filename.isEmpty()) {
         return QStringList();
@@ -167,7 +162,7 @@ QStringList FileListHelper::expandJoker(const QUrl &url)
 
     QStringList foundPaths;
     const QStringList files = info.dir().entryList(QStringList(filename), QDir::Files | QDir::NoSymLinks);
-    foreach (const QString &file, files) {
+    for (const QString &file : files) {
         foundPaths.append(info.dir().absoluteFilePath(file));
     }
 
@@ -178,8 +173,8 @@ void FileListHelper::setEnabledAction(QPushButton *button, bool enabled)
 {
     button->setEnabled(enabled);
 
-    QList<QAction *> actions = button->actions();
-    foreach (QAction *action, actions) {
+    const QList<QAction *> actions = button->actions();
+    for (QAction *action : actions) {
         action->setEnabled(enabled);
     }
 }
