@@ -22,16 +22,13 @@
 #include "multipleFileList.h"
 
 #include <QAction>
-#include <QPushButton>
 #include <QHeaderView>
+#include <QPushButton>
 
 #include <KLocalizedString>
-#include <KActionCollection>
-#include <KMessageBox>
 
-#include <QIcon>
-#include <QMenu>
 #include <QFileInfo>
+#include <QIcon>
 
 #include "defaults.h"
 
@@ -39,52 +36,46 @@
 
 MultipleFileList::MultipleFileList(QWidget *parent, const QString &descriptionText)
     : QWidget(parent)
-    , fileListHelper(this)
+    , mFileListHelper(this)
 {
     logDebug() << "Initializing multiple file list...";
 
     setupUi(this);
 
-    missingFiles = false;
-    warningBox = new KMessageWidget(this);
-    warningBox->setVisible(false);
-    warningBox->setMessageType(KMessageWidget::Warning);
-    warningBox->setText(i18n("Some log files do not exist.\n"
-                             "Modes with missing log files will be unavailable."));
-    warningBox->setCloseButtonVisible(false);
-    warningBox->setIcon(QIcon::fromTheme(QStringLiteral("dialog-warning")));
-    vboxLayout->insertWidget(1, warningBox);
+    mWarningBox = new KMessageWidget(this);
+    mWarningBox->setVisible(false);
+    mWarningBox->setMessageType(KMessageWidget::Warning);
+    mWarningBox->setText(
+        i18n("Some log files do not exist.\n"
+             "Modes with missing log files will be unavailable."));
+    mWarningBox->setCloseButtonVisible(false);
+    mWarningBox->setIcon(QIcon::fromTheme(QStringLiteral("dialog-warning")));
+    vboxLayout->insertWidget(1, mWarningBox);
 
     description->setText(descriptionText);
 
-    fileListHelper.prepareButton(modify, QIcon::fromTheme(QStringLiteral("document-open")), this,
-                                 SLOT(modifyItem()), fileList);
+    mFileListHelper.prepareButton(modify, QIcon::fromTheme(QStringLiteral("document-open")), this, SLOT(modifyItem()), fileList);
 
     fileList->header()->setVisible(false);
 
     // Add a separator in the MultipleFileList
-    QAction *separator = new QAction(this);
+    auto separator = new QAction(this);
     separator->setSeparator(true);
     fileList->addAction(separator);
 
-    fileListHelper.prepareButton(remove, QIcon::fromTheme(QStringLiteral("list-remove")), this,
-                                 SLOT(removeSelectedItem()), fileList);
+    mFileListHelper.prepareButton(remove, QIcon::fromTheme(QStringLiteral("list-remove")), this, SLOT(removeSelectedItem()), fileList);
 
-    fileListHelper.prepareButton(up, QIcon::fromTheme(QStringLiteral("go-up")), this, SLOT(moveUpItem()),
-                                 fileList);
+    mFileListHelper.prepareButton(up, QIcon::fromTheme(QStringLiteral("go-up")), this, SLOT(moveUpItem()), fileList);
 
-    fileListHelper.prepareButton(down, QIcon::fromTheme(QStringLiteral("go-down")), this, SLOT(moveDownItem()),
-                                 fileList);
+    mFileListHelper.prepareButton(down, QIcon::fromTheme(QStringLiteral("go-down")), this, SLOT(moveDownItem()), fileList);
 
-    fileListHelper.prepareButton(removeAll, QIcon::fromTheme(QStringLiteral("trash-empty")), this,
-                                 SLOT(removeAllItems()), fileList);
+    mFileListHelper.prepareButton(removeAll, QIcon::fromTheme(QStringLiteral("trash-empty")), this, SLOT(removeAllItems()), fileList);
 
     connect(fileList, &QTreeWidget::itemSelectionChanged, this, &MultipleFileList::updateButtons);
-    connect(fileList, SIGNAL(itemDoubleClicked(QTreeWidgetItem*,int)), this,
-            SLOT(modifyItem(QTreeWidgetItem*)));
+    connect(fileList, SIGNAL(itemDoubleClicked(QTreeWidgetItem *, int)), this, SLOT(modifyItem(QTreeWidgetItem *)));
     connect(this, &MultipleFileList::fileListChanged, this, &MultipleFileList::updateButtons);
 
-    connect(&addButtons, SIGNAL(buttonClicked(int)), this, SLOT(addItem(int)));
+    connect(&mAddButtons, SIGNAL(buttonClicked(int)), this, SLOT(addItem(int)));
 
     updateButtons();
 
@@ -99,46 +90,48 @@ void MultipleFileList::updateButtons()
 {
     logDebug() << "Updating buttons...";
 
-    if (isFileListsEmpty() == true)
-        fileListHelper.setEnabledAction(removeAll, false);
-    else
-        fileListHelper.setEnabledAction(removeAll, true);
+    if (isFileListsEmpty()) {
+        mFileListHelper.setEnabledAction(removeAll, false);
+    } else {
+        mFileListHelper.setEnabledAction(removeAll, true);
+    }
 
-    QList<QTreeWidgetItem *> selectedItems = fileList->selectedItems();
+    const QList<QTreeWidgetItem *> selectedItems = fileList->selectedItems();
 
     // If the selection is not empty and a empty item is not selected
     QTreeWidgetItem *categoryItem = nullptr;
-    if (selectedItems.isEmpty() == false && isEmptyItem(selectedItems.at(0)) == false) {
+    if (!selectedItems.isEmpty() && !isEmptyItem(selectedItems.at(0))) {
         categoryItem = findCategoryOfChild(selectedItems.at(0));
     }
 
-    if (categoryItem != nullptr) {
-        int categoryIndex = fileList->indexOfTopLevelItem(categoryItem);
+    if (categoryItem) {
+        const int categoryIndex = fileList->indexOfTopLevelItem(categoryItem);
 
-        fileListHelper.setEnabledAction(remove, true);
-        fileListHelper.setEnabledAction(modify, true);
+        mFileListHelper.setEnabledAction(remove, true);
+        mFileListHelper.setEnabledAction(modify, true);
 
         QTreeWidgetItem *selectedItem = selectedItems.at(0);
 
         // If the item is at the top of the list, it could not be upped anymore
-        if (categoryItem->indexOfChild(selectedItem) == 0)
-            fileListHelper.setEnabledAction(up, false);
-        else
-            fileListHelper.setEnabledAction(up, true);
+        if (categoryItem->indexOfChild(selectedItem) == 0) {
+            mFileListHelper.setEnabledAction(up, false);
+        } else {
+            mFileListHelper.setEnabledAction(up, true);
+        }
 
         // If the item is at bottom of the list, it could not be downed anymore
-        if (categoryItem->indexOfChild(selectedItem) == categoryCount(categoryIndex) - 1)
-            fileListHelper.setEnabledAction(down, false);
-        else
-            fileListHelper.setEnabledAction(down, true);
-
+        if (categoryItem->indexOfChild(selectedItem) == categoryCount(categoryIndex) - 1) {
+            mFileListHelper.setEnabledAction(down, false);
+        } else {
+            mFileListHelper.setEnabledAction(down, true);
+        }
     }
     // If nothing is selected, disabled special buttons
     else {
-        fileListHelper.setEnabledAction(remove, false);
-        fileListHelper.setEnabledAction(modify, false);
-        fileListHelper.setEnabledAction(up, false);
-        fileListHelper.setEnabledAction(down, false);
+        mFileListHelper.setEnabledAction(remove, false);
+        mFileListHelper.setEnabledAction(modify, false);
+        mFileListHelper.setEnabledAction(up, false);
+        mFileListHelper.setEnabledAction(down, false);
     }
 
     logDebug() << "Buttons updated";
@@ -146,7 +139,7 @@ void MultipleFileList::updateButtons()
 
 bool MultipleFileList::isFileListsEmpty() const
 {
-    for (int i = 0; i < fileList->topLevelItemCount(); ++i) {
+    for (int i = 0, total = fileList->topLevelItemCount(); i < total; ++i) {
         if (categoryCount(i) != 0) {
             logDebug() << "Is not empty";
             return false;
@@ -159,7 +152,7 @@ bool MultipleFileList::isFileListsEmpty() const
 
 bool MultipleFileList::isOneOfCategoryEmpty() const
 {
-    for (int i = 0; i < fileList->topLevelItemCount(); ++i) {
+    for (int i = 0, total = fileList->topLevelItemCount(); i < total; ++i) {
         if (categoryCount(i) == 0) {
             logDebug() << "A category is empty";
             return true;
@@ -173,16 +166,17 @@ bool MultipleFileList::isOneOfCategoryEmpty() const
 int MultipleFileList::categoryCount(int index) const
 {
     QTreeWidgetItem *item = fileList->topLevelItem(index);
-    if (item == nullptr) {
+    if (!item) {
         logCritical() << "Index out of range" << index;
         return 0;
     }
 
     int count = 0;
-    for (int i = 0; i < item->childCount(); ++i) {
+    for (int i = 0, total = item->childCount(); i < total; ++i) {
         QTreeWidgetItem *childItem = item->child(i);
-        if (isEmptyItem(childItem) == false)
+        if (!isEmptyItem(childItem)) {
             count++;
+        }
     }
 
     return count;
@@ -190,7 +184,7 @@ int MultipleFileList::categoryCount(int index) const
 
 int MultipleFileList::addCategory(const QString &itemName, const QString &buttonName)
 {
-    QTreeWidgetItem *item = new QTreeWidgetItem(fileList, QStringList(itemName));
+    auto item = new QTreeWidgetItem(fileList, QStringList(itemName));
     item->setExpanded(true);
     QFont font = item->font(0);
     font.setBold(true);
@@ -198,14 +192,13 @@ int MultipleFileList::addCategory(const QString &itemName, const QString &button
 
     int index = fileList->indexOfTopLevelItem(item);
 
-    QPushButton *addButton = new QPushButton(buttonName, this);
-    QAction *action
-        = fileListHelper.prepareButtonAndAction(addButton, QIcon::fromTheme(QStringLiteral("document-new")));
+    auto addButton = new QPushButton(buttonName, this);
+    QAction *action = mFileListHelper.prepareButtonAndAction(addButton, QIcon::fromTheme(QStringLiteral("document-new")));
 
     // Insert the action in first position
-    fileList->insertAction(fileList->actions().at(addButtons.buttons().size()), action);
+    fileList->insertAction(fileList->actions().at(mAddButtons.buttons().size()), action);
 
-    addButtons.addButton(addButton, index);
+    mAddButtons.addButton(addButton, index);
 
     vboxLayout1->insertWidget(index, addButton);
 
@@ -221,28 +214,28 @@ void MultipleFileList::addItem(int category)
     logDebug() << "Adding item" << category;
 
     // Open a standard Filedialog
-    QList<QUrl> urls = fileListHelper.openUrls();
+    const QList<QUrl> urls = mFileListHelper.openUrls();
 
     QTreeWidgetItem *categoryItem = fileList->topLevelItem(category);
 
-    QStringList paths = fileListHelper.findPaths(urls);
-    foreach (const QString &path, paths) {
+    const QStringList paths = mFileListHelper.findPaths(urls);
+    for (const QString &path : paths) {
         addItemInternal(categoryItem, path);
     }
 
     updateEmptyItems();
 
-    emit fileListChanged();
+    Q_EMIT fileListChanged();
 }
 
 void MultipleFileList::addItemInternal(QTreeWidgetItem *categoryItem, const QString &path)
 {
     logDebug() << "Adding" << path << "to" << categoryItem->text(0);
-    QTreeWidgetItem *item = new QTreeWidgetItem(QStringList(path));
+    auto item = new QTreeWidgetItem(QStringList(path));
 
     QFileInfo checkFile(path);
     if (!checkFile.exists()) {
-        missingFiles = true;
+        mMissingFiles = true;
         item->setForeground(0, Qt::red);
     }
 
@@ -254,7 +247,7 @@ QTreeWidgetItem *MultipleFileList::findCategoryOfChild(QTreeWidgetItem *childIte
 {
     logDebug() << "Finding Category of" << childItem->text(0);
 
-    for (int i = 0; i < fileList->topLevelItemCount(); ++i) {
+    for (int i = 0, total = fileList->topLevelItemCount(); i < total; ++i) {
         QTreeWidgetItem *item = fileList->topLevelItem(i);
 
         if (item->indexOfChild(childItem) != -1) {
@@ -269,47 +262,49 @@ QTreeWidgetItem *MultipleFileList::findCategoryOfChild(QTreeWidgetItem *childIte
 
 void MultipleFileList::modifyItem()
 {
-    QList<QTreeWidgetItem *> selectedItems = fileList->selectedItems();
+    const QList<QTreeWidgetItem *> selectedItems = fileList->selectedItems();
     modifyItem(selectedItems.at(0));
 }
 
 void MultipleFileList::modifyItem(QTreeWidgetItem *item)
 {
     // If the user tries to modify a category item, we do nothing
-    if (findCategoryOfChild(item) == nullptr || isEmptyItem(item) == true)
+    if (!findCategoryOfChild(item) || isEmptyItem(item)) {
         return;
+    }
 
-    QString previousPath = item->text(0);
+    const QString previousPath = item->text(0);
 
     // Open a standard Filedialog
-    QUrl url = fileListHelper.openUrl(previousPath);
-    if (url.isEmpty())
+    const QUrl url = mFileListHelper.openUrl(previousPath);
+    if (url.isEmpty()) {
         return;
+    }
 
     QList<QUrl> urls;
     urls.append(url);
-    QStringList paths = fileListHelper.findPaths(urls);
+    const QStringList paths = mFileListHelper.findPaths(urls);
 
     // We only take the first path
     if (paths.count() >= 1) {
         item->setText(0, paths.at(0));
     }
 
-    emit fileListChanged();
+    Q_EMIT fileListChanged();
 }
 
 void MultipleFileList::removeSelectedItem()
 {
-    QList<QTreeWidgetItem *> selectedItems = fileList->selectedItems();
+    const QList<QTreeWidgetItem *> selectedItems = fileList->selectedItems();
 
-    foreach (QTreeWidgetItem *item, selectedItems) {
+    for (QTreeWidgetItem *item : selectedItems) {
         QTreeWidgetItem *categoryItem = findCategoryOfChild(item);
         delete categoryItem->takeChild(categoryItem->indexOfChild(item));
     }
 
     updateEmptyItems();
 
-    emit fileListChanged();
+    Q_EMIT fileListChanged();
 }
 
 void MultipleFileList::moveItem(int direction)
@@ -330,7 +325,7 @@ void MultipleFileList::moveItem(int direction)
     fileList->setCurrentItem(item);
     // item->setSelected(true);
 
-    emit fileListChanged();
+    Q_EMIT fileListChanged();
 }
 
 void MultipleFileList::moveUpItem()
@@ -346,7 +341,7 @@ void MultipleFileList::moveDownItem()
 void MultipleFileList::removeAllItems()
 {
     QTreeWidgetItemIterator it(fileList, QTreeWidgetItemIterator::All);
-    while (*it != nullptr) {
+    while (*it) {
         QTreeWidgetItem *item = *it;
 
         QList<QTreeWidgetItem *> children = item->takeChildren();
@@ -359,13 +354,13 @@ void MultipleFileList::removeAllItems()
 
     updateEmptyItems();
 
-    emit fileListChanged();
+    Q_EMIT fileListChanged();
 }
 
 void MultipleFileList::unselectAllItems()
 {
-    QList<QTreeWidgetItem *> selectedItems = fileList->selectedItems();
-    foreach (QTreeWidgetItem *item, selectedItems) {
+    const QList<QTreeWidgetItem *> selectedItems = fileList->selectedItems();
+    for (QTreeWidgetItem *item : selectedItems) {
         item->setSelected(false);
     }
 }
@@ -376,7 +371,7 @@ void MultipleFileList::updateEmptyItems()
 
     logDebug() << "Adding empty items...";
 
-    for (int i = 0; i < fileList->topLevelItemCount(); ++i) {
+    for (int i = 0, total = fileList->topLevelItemCount(); i < total; ++i) {
         QTreeWidgetItem *categoryItem = fileList->topLevelItem(i);
 
         // If it's a category item and it's empty
@@ -403,7 +398,7 @@ void MultipleFileList::removeEmptyItems()
         for (int i = 0; i < categoryItem->childCount(); ++i) {
             QTreeWidgetItem *childItem = categoryItem->child(i);
 
-            if (isEmptyItem(childItem) == true && categoryItem->childCount() > 1) {
+            if (isEmptyItem(childItem) && categoryItem->childCount() > 1) {
                 logDebug() << "Remove a child item";
                 delete categoryItem->takeChild(i);
                 break;
@@ -416,17 +411,18 @@ void MultipleFileList::removeEmptyItems()
 
 bool MultipleFileList::isEmptyItem(QTreeWidgetItem *item) const
 {
-    if (item->font(0).italic() == true)
+    if (item->font(0).italic()) {
         return true;
-    else
+    } else {
         return false;
+    }
 }
 
 void MultipleFileList::addEmptyItem(QTreeWidgetItem *item)
 {
     logDebug() << "Adding an empty item...";
 
-    QTreeWidgetItem *emptyItem = new QTreeWidgetItem(item, QStringList(i18n("No log file...")));
+    auto emptyItem = new QTreeWidgetItem(item, QStringList(i18n("No log file...")));
     item->setExpanded(true);
     QFont font = emptyItem->font(0);
     font.setItalic(true);
@@ -435,10 +431,10 @@ void MultipleFileList::addEmptyItem(QTreeWidgetItem *item)
 
 void MultipleFileList::addPaths(int category, const QStringList &paths)
 {
-    missingFiles = false;
+    mMissingFiles = false;
     QTreeWidgetItem *categoryItem = fileList->topLevelItem(category);
 
-    foreach (const QString &path, paths) {
+    for (const QString &path : paths) {
         addItemInternal(categoryItem, path);
     }
 
@@ -446,7 +442,7 @@ void MultipleFileList::addPaths(int category, const QStringList &paths)
 
     updateButtons();
 
-    warningBox->setVisible(missingFiles);
+    mWarningBox->setVisible(mMissingFiles);
 }
 
 QStringList MultipleFileList::paths(int category)
@@ -455,7 +451,7 @@ QStringList MultipleFileList::paths(int category)
     QTreeWidgetItemIterator it(fileList, QTreeWidgetItemIterator::All);
 
     QStringList paths;
-    while (*it != nullptr) {
+    while (*it) {
         QTreeWidgetItem *item = *it;
 
         if (categoryItem->indexOfChild(item) != -1) {
