@@ -20,6 +20,7 @@
  ***************************************************************************/
 
 #include "cupsAnalyzer.h"
+#include <KLocalizedString>
 
 CupsAnalyzer::CupsAnalyzer(LogMode *logMode)
     : FileAnalyzer(logMode)
@@ -54,44 +55,40 @@ LogLine *CupsAnalyzer::parseMessage(const QString &logLine, const LogFile &origi
 {
     QString line(logLine);
 
-    QChar level = logLine[0];
+    const QChar level = logLine[0];
 
-    QDateTime dateTime = ParsingHelper::instance()->parseHttpDateTime(logLine.mid(3, 26));
+    const QDateTime dateTime = ParsingHelper::instance()->parseHttpDateTime(logLine.mid(3, 26));
 
-    QString message = line.remove(0, 31);
+    const QString message = line.remove(0, 31);
 
-    QStringList list;
-    list.append(message);
+    const QStringList list{message};
 
-    return new LogLine(logLineInternalIdGenerator++, dateTime, list, originalLogFile.url().toLocalFile(),
-                       findLogLevel(level), logMode);
+    return new LogLine(mLogLineInternalIdGenerator++, dateTime, list, originalLogFile.url().toLocalFile(), findLogLevel(level), mLogMode);
 }
 
 void CupsAnalyzer::initializeTypeLevels()
 {
-    mapTypeLevels[QLatin1Char('d')] = new LogLevel(20, i18n("debug 2"), QStringLiteral(DEBUG2_LOG_LEVEL_ICON),
-                                                   QColor(169, 189, 165), this);
-    mapTypeLevels[QLatin1Char('D')] = Globals::instance().debugLogLevel();
-    mapTypeLevels[QLatin1Char('I')] = Globals::instance().informationLogLevel();
-    mapTypeLevels[QLatin1Char('N')] = Globals::instance().noticeLogLevel();
-    mapTypeLevels[QLatin1Char('W')] = Globals::instance().warningLogLevel();
-    mapTypeLevels[QLatin1Char('E')] = Globals::instance().errorLogLevel();
-    mapTypeLevels[QLatin1Char('C')] = Globals::instance().criticalLogLevel();
-    mapTypeLevels[QLatin1Char('A')] = Globals::instance().alertLogLevel();
-    mapTypeLevels[QLatin1Char('X')] = Globals::instance().emergencyLogLevel();
-    mapTypeLevels[QLatin1Char(' ')] = Globals::instance().noLogLevel();
+    mMapTypeLevels[QLatin1Char('d')] = new LogLevel(20, i18n("debug 2"), QStringLiteral(DEBUG2_LOG_LEVEL_ICON), QColor(169, 189, 165), this);
+    mMapTypeLevels[QLatin1Char('D')] = Globals::instance().debugLogLevel();
+    mMapTypeLevels[QLatin1Char('I')] = Globals::instance().informationLogLevel();
+    mMapTypeLevels[QLatin1Char('N')] = Globals::instance().noticeLogLevel();
+    mMapTypeLevels[QLatin1Char('W')] = Globals::instance().warningLogLevel();
+    mMapTypeLevels[QLatin1Char('E')] = Globals::instance().errorLogLevel();
+    mMapTypeLevels[QLatin1Char('C')] = Globals::instance().criticalLogLevel();
+    mMapTypeLevels[QLatin1Char('A')] = Globals::instance().alertLogLevel();
+    mMapTypeLevels[QLatin1Char('X')] = Globals::instance().emergencyLogLevel();
+    mMapTypeLevels[QLatin1Char(' ')] = Globals::instance().noLogLevel();
 }
 
-LogLevel *CupsAnalyzer::findLogLevel(const QChar &type)
+LogLevel *CupsAnalyzer::findLogLevel(QChar type)
 {
     QMap<QChar, LogLevel *>::iterator it;
 
-    it = mapTypeLevels.find(type);
-    if (it != mapTypeLevels.end()) {
-        return (*it);
+    it = mMapTypeLevels.find(type);
+    if (it != mMapTypeLevels.end()) {
+        return *it;
     } else {
-        logCritical() << i18n(
-            "New Log Level detected: Please send this log file to the KSystemLog developer to add it.");
-        return (Globals::instance().noLogLevel());
+        logCritical() << i18n("New Log Level detected: Please send this log file to the KSystemLog developer to add it.");
+        return Globals::instance().noLogLevel();
     }
 }
