@@ -31,29 +31,21 @@
 #include "logging.h"
 
 #include "logLine.h"
-#include "logViewWidgetItem.h"
 #include "logMode.h"
+#include "logViewWidgetItem.h"
 
 class CupsItemBuilder : public LogModeItemBuilder
 {
 public:
-    CupsItemBuilder() {}
-
-    virtual ~CupsItemBuilder() {}
-
-    QString createFormattedText(LogLine *line) const override
+    CupsItemBuilder()
     {
-        QString result;
-
-        result.append(QLatin1String("<table>"));
-
-        result.append(labelMessageFormat(i18n("Date:"), formatDate(line->time())));
-        result.append(labelMessageFormat(i18n("Level:"), line->logLevel()->name()));
-
-        result.append(QLatin1String("</table>"));
-
-        return result;
     }
+
+    ~CupsItemBuilder() override
+    {
+    }
+
+    QString createFormattedText(LogLine *line) const override;
 };
 
 #endif // _CUPS_ITEM_BUILDER_H
