@@ -29,8 +29,8 @@
 #include "logging.h"
 
 #include "logLine.h"
-#include "logViewWidgetItem.h"
 #include "logMode.h"
+#include "logViewWidgetItem.h"
 
 #include "logModeItemBuilder.h"
 
@@ -39,26 +39,15 @@ class LogLine;
 class KernelItemBuilder : public LogModeItemBuilder
 {
 public:
-    KernelItemBuilder() {}
-
-    virtual ~KernelItemBuilder() {}
-
-    QString createFormattedText(LogLine *line) const override
+    KernelItemBuilder()
     {
-        QString result;
-
-        QListIterator<QString> it(line->logItems());
-
-        result.append(QLatin1String("<table>"));
-
-        result.append(labelMessageFormat(i18n("Date:"), formatDate(line->time())));
-        result.append(labelMessageFormat(i18n("Level:"), line->logLevel()->name()));
-        result.append(labelMessageFormat(i18n("Component:"), it.next()));
-
-        result.append(QLatin1String("</table>"));
-
-        return result;
     }
+
+    ~KernelItemBuilder() override
+    {
+    }
+
+    QString createFormattedText(LogLine *line) const override;
 };
 
 #endif // _KERNEL_ITEM_BUILDER_H
