@@ -20,10 +20,11 @@
  ***************************************************************************/
 
 #include "xorgAnalyzer.h"
+#include <KLocalizedString>
 
 XorgAnalyzer::XorgAnalyzer(LogMode *logMode)
     : FileAnalyzer(logMode)
-    , currentDateTime(QDateTime::currentDateTime())
+    , mCurrentDateTime(QDateTime::currentDateTime())
 {
     initializeTypeName();
 }
@@ -60,14 +61,12 @@ LogLine *XorgAnalyzer::parseMessage(const QString &logLine, const LogFile &origi
 {
     QString string(logLine);
 
-    QString type;
-
-    type = string.left(4);
+    const QString type = string.left(4);
 
     LogLevel *logLineType = findTypeName(type);
 
     // If the type is not empty, the log message has a type, so we can delete it
-    if (logLineType != nullptr) {
+    if (logLineType) {
         string.remove(0, 5);
     } else {
         logLineType = Globals::instance().informationLogLevel();
@@ -77,46 +76,40 @@ LogLine *XorgAnalyzer::parseMessage(const QString &logLine, const LogFile &origi
     list.append(logLineType->name());
     list.append(string);
 
-    return new LogLine(logLineInternalIdGenerator++, currentDateTime, list, originalFile.url().toLocalFile(),
-                       logLineType, logMode);
+    return new LogLine(mLogLineInternalIdGenerator++, mCurrentDateTime, list, originalFile.url().toLocalFile(), logLineType, mLogMode);
 }
 
 void XorgAnalyzer::initializeTypeName()
 {
-    xorgLevels[QStringLiteral("(--)")] = new LogLevel(
-        1001, i18n("Probed"), QStringLiteral(PROBED_LOG_LEVEL_ICON), QColor(246, 206, 30), this);
+    mXorgLevels[QStringLiteral("(--)")] = new LogLevel(1001, i18n("Probed"), QStringLiteral(PROBED_LOG_LEVEL_ICON), QColor(246, 206, 30), this);
 
-    xorgLevels[QStringLiteral("(**)")]
-        = new LogLevel(1002, i18n("From config file"), QStringLiteral(CONFIG_FILE_LOG_LEVEL_ICON),
-                       QColor(161, 133, 240), this);
+    mXorgLevels[QStringLiteral("(**)")] = new LogLevel(1002, i18n("From config file"), QStringLiteral(CONFIG_FILE_LOG_LEVEL_ICON), QColor(161, 133, 240), this);
 
-    xorgLevels[QStringLiteral("(==)")]
-        = new LogLevel(1003, i18n("Default setting"), QStringLiteral(DEFAULT_SETTING_LOG_LEVEL_ICON),
-                       QColor(169, 189, 165), this);
+    mXorgLevels[QStringLiteral("(==)")] =
+        new LogLevel(1003, i18n("Default setting"), QStringLiteral(DEFAULT_SETTING_LOG_LEVEL_ICON), QColor(169, 189, 165), this);
 
-    xorgLevels[QStringLiteral("(++)")]
-        = new LogLevel(1004, i18n("From command Line"), QStringLiteral(COMMAND_LINE_LOG_LEVEL_ICON),
-                       QColor(179, 181, 214), this);
+    mXorgLevels[QStringLiteral("(++)")] =
+        new LogLevel(1004, i18n("From command Line"), QStringLiteral(COMMAND_LINE_LOG_LEVEL_ICON), QColor(179, 181, 214), this);
 
-    xorgLevels[QStringLiteral("(!!)")] = Globals::instance().noticeLogLevel();
-    xorgLevels[QStringLiteral("(II)")] = Globals::instance().informationLogLevel();
-    xorgLevels[QStringLiteral("(WW)")] = Globals::instance().warningLogLevel();
-    xorgLevels[QStringLiteral("(EE)")] = Globals::instance().errorLogLevel();
+    mXorgLevels[QStringLiteral("(!!)")] = Globals::instance().noticeLogLevel();
+    mXorgLevels[QStringLiteral("(II)")] = Globals::instance().informationLogLevel();
+    mXorgLevels[QStringLiteral("(WW)")] = Globals::instance().warningLogLevel();
+    mXorgLevels[QStringLiteral("(EE)")] = Globals::instance().errorLogLevel();
 
-    xorgLevels[QStringLiteral("(NI)")]
-        = new LogLevel(1005, i18n("Not implemented"), QStringLiteral(NOT_IMPLEMENTED_LOG_LEVEL_ICON),
-                       QColor(136, 146, 240), this);
+    mXorgLevels[QStringLiteral("(NI)")] =
+        new LogLevel(1005, i18n("Not implemented"), QStringLiteral(NOT_IMPLEMENTED_LOG_LEVEL_ICON), QColor(136, 146, 240), this);
 
-    xorgLevels[QStringLiteral("(\?\?)")] = Globals::instance().noLogLevel();
+    mXorgLevels[QStringLiteral("(\?\?)")] = Globals::instance().noLogLevel();
 }
 
 LogLevel *XorgAnalyzer::findTypeName(const QString &type)
 {
     QMap<QString, LogLevel *>::iterator it;
 
-    it = xorgLevels.find(type);
-    if (it != xorgLevels.end())
+    it = mXorgLevels.find(type);
+    if (it != mXorgLevels.end()) {
         return *it;
-    else
+    } else {
         return nullptr;
+    }
 }
