@@ -21,18 +21,15 @@
 
 #include "xorgFactory.h"
 
-
 #include "logMode.h"
 #include "logging.h"
 
 #include "simpleAction.h"
 #include "xorgLogMode.h"
 
-
 QList<LogMode *> XorgLogModeFactory::createLogModes() const
 {
-    QList<LogMode *> logModes;
-    logModes.append(new XorgLogMode());
+    const QList<LogMode *> logModes{new XorgLogMode()};
     return logModes;
 }
 
@@ -40,10 +37,11 @@ LogModeAction *XorgLogModeFactory::createLogModeAction() const
 {
     LogMode *logMode = Globals::instance().findLogMode(QStringLiteral(XORG_LOG_MODE_ID));
 
-    if (!logMode->filesExist())
+    if (!logMode->filesExist()) {
         return nullptr;
+    }
 
-    SimpleAction *logModeAction = new SimpleAction(logMode->action(), logMode);
+    auto logModeAction = new SimpleAction(logMode->action(), logMode);
 
     logModeAction->setCategory(LogModeAction::ServicesCategory);
 
