@@ -29,8 +29,8 @@
 #include "logging.h"
 
 #include "logLine.h"
-#include "logViewWidgetItem.h"
 #include "logMode.h"
+#include "logViewWidgetItem.h"
 
 #include "logModeItemBuilder.h"
 
@@ -39,51 +39,19 @@ class LogLine;
 class XSessionItemBuilder : public LogModeItemBuilder
 {
 public:
-    XSessionItemBuilder() {}
-
-    ~XSessionItemBuilder() override {}
-
-    void prepareItem(LogViewWidgetItem *item) const override
+    XSessionItemBuilder()
     {
-        LogLine *line = item->logLine();
-
-        item->setText(0, QLatin1String(""));
-
-        int i = 1;
-        foreach (const QString &label, line->logItems()) {
-            item->setText(i, label);
-            i++;
-        }
-
-        item->setIcon(0, line->logLevel()->icon());
     }
 
-    QString createToolTipText(LogLine *line) const override
+    ~XSessionItemBuilder() override
     {
-        QString result;
-
-        QListIterator<QString> it(line->logItems());
-
-        result.append(QLatin1String("<table>"));
-
-        QString type = it.next();
-        if (type.isEmpty())
-            result.append(labelMessageFormat(i18n("Program:"), i18n("none")));
-        else
-            result.append(labelMessageFormat(i18n("Program:"), type));
-
-        result.append(labelMessageFormat(i18n("Original file:"), line->sourceFileName()));
-
-        result.append(QLatin1String("</table>"));
-
-        return result;
     }
 
-    QString createFormattedText(LogLine *line) const override
-    {
-        // It uses the same formating than the tool tip
-        return createToolTipText(line);
-    }
+    void prepareItem(LogViewWidgetItem *item) const override;
+
+    QString createToolTipText(LogLine *line) const override;
+
+    QString createFormattedText(LogLine *line) const override;
 };
 
 #endif // _X_SESSION_ITEM_BUILDER_H
