@@ -25,11 +25,11 @@
 #include <QStatusBar>
 
 class QString;
-
+class QLabel;
+class QComboBox;
+class QPushButton;
 namespace KSystemLog
 {
-class StatusBarPrivate;
-
 /**
  * Status Bar
  */
@@ -40,7 +40,7 @@ class StatusBar : public QStatusBar
 public:
     explicit StatusBar(QWidget *parent);
 
-    virtual ~StatusBar();
+    ~StatusBar() override;
 
     void changeLineCountMessage(const QString &lineCountMessage);
     void changeLastModification(const QTime &lastModification);
@@ -52,7 +52,10 @@ private Q_SLOTS:
     void selectLastHistory();
 
 private:
-    StatusBarPrivate *const d;
+    QLabel *mLineCountLabel = nullptr;
+    QComboBox *mMessageList = nullptr;
+    QLabel *mLastModificationLabel = nullptr;
+    QPushButton *mToggleHistory = nullptr;
 };
 }
 
